package pipeClient;

import java.io.UnsupportedEncodingException;

import pipeClient.PacketHeader.DataBlockTypeEnum;

public class Event
{
	private final String encoding = "UTF-16LE";
	
	public enum EventSourceEnum 
	{
		Undefined,
		Application,
		Stimulator,
		DigitalIn,
		Timer
	}
	
	private EventSourceEnum eventSource;
	private int id;
	private long timeStamp;
	private int data;
	private String label;

	public long getTimeStamp()
	{
		return timeStamp;
	}

	public void setTimeStamp(long timeStamp)
	{
		this.timeStamp = timeStamp;
	}

	public int getData()
	{
		return data;
	}

	public void setData(int data)
	{
		this.data = data;
	}

	public String getLabel()
	{
		return label;
	}

	public void setLabel(String label)
	{
		this.label = label;
	}

	public int getID()
	{
		return id;
	}

	public void setID(int id)
	{
		this.id = id;
	}

	public EventSourceEnum getEventSource()
	{
		return eventSource;
	}

	public void setEventSource(EventSourceEnum eventSource)
	{
		this.eventSource = eventSource;
	}
	
	public Event()
	{
		eventSource = EventSourceEnum.Undefined;
		id = -1;
		timeStamp = -1;
		data = 0;
		label = "";
	}
	
	public Event(byte[] array)
	{
		this.eventSource = getEventSourceEnum(BitConverter.toInt(array, 0));
		this.id = BitConverter.toInt(array, 4);
		this.timeStamp = BitConverter.toLong(array, 8);
		this.data = BitConverter.toInt(array, 16);
		
		int labelLength = array.length - 20;
		byte[] valueArray = new byte[labelLength];
		System.arraycopy(array, 20, valueArray, 0, labelLength);
		try
		{
			this.label = new String(valueArray, encoding);
		} 
		catch (UnsupportedEncodingException e)
		{
			e.printStackTrace();
		}
	}
	
	private int getEventSourceValue(EventSourceEnum source) 
	{
		switch (source) 
		{
			case Undefined:
				return -1;
			case Application:
				return 1;
			case Stimulator:
				return 2;
			case DigitalIn:
				return 3;
			case Timer:
				return 4;
		}
		
		throw new IllegalArgumentException("Type is not valid");
	}
	
	private EventSourceEnum getEventSourceEnum(int source)
	{
		switch (source)
		{
			case -1:
				return EventSourceEnum.Undefined;
			case 1:
				return EventSourceEnum.Application;
			case 2:
				return EventSourceEnum.Stimulator;
			case 3:
				return EventSourceEnum.DigitalIn;
			case 4:
				return EventSourceEnum.Timer;
		}
		
		throw new IllegalArgumentException("Type is not valid");
	}
}
