package pipeClient;

public class PacketHeader 
{

	public enum DataBlockTypeEnum 
	{
		Undefined,
		Handshake,
		MonitorInfo,
		SpikeData,
		Event
	}
	
	private DataBlockTypeEnum dataBlockType;
	private int dataBlockSize;
	private int itemSize;
	private final int sizeOfInt = 4;
	
	public DataBlockTypeEnum getDataBlockType() 
	{
		return dataBlockType;
	}

	public void setDataBlockType(DataBlockTypeEnum dataBlockType) 
	{
		this.dataBlockType = dataBlockType;
	}

	public int getDataBlockSize() 
	{
		return dataBlockSize;
	}

	public void setDataBlockSize(int dataBlockSize) 
	{
		this.dataBlockSize = dataBlockSize;
	}

	public int getItemSize() 
	{
		return itemSize;
	}

	public void setItemSize(int itemSize) 
	{
		this.itemSize = itemSize;
	}
	
	public PacketHeader() 
	{
		dataBlockType = DataBlockTypeEnum.Undefined;
		dataBlockSize = -1;
		itemSize = -1;
	}
	
	public int getLength() 
	{
		return 3 * sizeOfInt;
	}
	
	public void set(byte[] array) 
	{
		int type = BitConverter.toInt(array, 0);
		dataBlockType = getDataBlockTypeEnum(type);
		dataBlockSize = BitConverter.toInt(array, sizeOfInt);
		itemSize = BitConverter.toInt(array, 2 * sizeOfInt);
	}
	
	public byte[] toArray() 
	{
		byte[] array = new byte[3 * sizeOfInt];
		
		byte[] typeArray = BitConverter.toBytes(getDataBlockTypeValue(dataBlockType));
		byte[] blockSizeArray = BitConverter.toBytes(dataBlockSize);
		byte[] itemSizeArray = BitConverter.toBytes(itemSize);
		
		System.arraycopy(typeArray, 0, array, 0, sizeOfInt);
		System.arraycopy(blockSizeArray, 0, array, sizeOfInt, sizeOfInt);
		System.arraycopy(itemSizeArray, 0, array, 2*sizeOfInt, sizeOfInt);
		
		return array;
	}
	
	private int getDataBlockTypeValue(DataBlockTypeEnum type) 
	{
		switch (type) 
		{
			case Handshake:
				return 1;
			case Event:
				return 2;
			case SpikeData:
				return 3;
			case Undefined:
				return -1;
		}
		throw new IllegalArgumentException("Type is not valid");
	}
	
	private DataBlockTypeEnum getDataBlockTypeEnum(int type) 
	{
		switch (type) 
		{
			case 1:
				return DataBlockTypeEnum.Handshake;
			case 2:
				return DataBlockTypeEnum.Event;
			case 3:
				return DataBlockTypeEnum.SpikeData;
			case -1:
				return DataBlockTypeEnum.Undefined;
		}
		
		throw new IllegalArgumentException("Type is not valid");
	}
}
