package pipeClientThread;

import java.util.HashMap;
import java.util.LinkedList;

import pipeClient.Event;
import pipeClient.PipeClient;
import pipeClient.PipeClient.EventEvent;
import pipeClient.PipeClient.StateEvent;
import pipeClient.PipeClientListener;
import pipeClient.Spike;

public class McsCMOSPipeClientThread extends Thread implements PipeClientListener 
{

	private String address;
	private PipeClient client;
	private HashMap<Integer, LinkedList<Spike>> sensorData;
	private LinkedList<Event> eventData;
	private volatile boolean stop = false;
	
	public McsCMOSPipeClientThread(String address)
	{
		this.address = address;
		
		sensorData = new HashMap<Integer, LinkedList<Spike>>();
		eventData = new LinkedList<Event>();
		
		client = new PipeClient();
		client.addListener(this);
	}
	
	public boolean connect()
	{
		client.start(address);
		return client.connect();
	}
	
	@Override
	public void run()
	{
		while (!stop)
		{
			client.listenForData();
		}
		client.close();
		try
		{
			join();
		} 
		catch (InterruptedException e)
		{
			e.printStackTrace();
		}
	}
	
	public void terminate()
	{
		stop = true;
	}
	
	@Override
	public void signalClientState(StateEvent state)
	{
		System.out.println(state.getState() + ":");
		System.out.println(state.getMessage());
	}

	@Override
	public void signalClientEvent(EventEvent event)
	{
		System.err.println(event.getEvent() + ":");
		System.err.println(event.getMessage());
	}

	@Override
	public void signalSpikeData(HashMap<Integer, LinkedList<Spike>> spikes)
	{
		synchronized(sensorData)
		{	
			for (Integer sensor : spikes.keySet())
			{
				if (sensorData.containsKey(sensor)) 
				{
					sensorData.get(sensor).addAll(spikes.get(sensor));
				}
				else 
				{
					sensorData.put(sensor, spikes.get(sensor));
				}
			}
		}
	}
	
	public int getAvailableSensors()
	{
		synchronized(sensorData)
		{
			return sensorData.size();
		}
	}
	
	public HashMap<Integer, LinkedList<Spike>> getSpikeData()
	{
		synchronized(sensorData)
		{
//			HashMap<Integer, LinkedList<Spike>> retMap = new HashMap<Integer, LinkedList<Spike>>();
//			
//			for (Integer sensor : sensorData.keySet())
//			{
//				LinkedList<Spike> l = new LinkedList<Spike>();
//				for (Spike s : sensorData.get(sensor))
//				{
//					l.add(s);
//				}
//				retMap.put(sensor, l);
//			}
			HashMap<Integer, LinkedList<Spike>> retMap = new HashMap<Integer, LinkedList<Spike>>(sensorData);
			
			sensorData.clear();
			return retMap;
		}
	}
	
	public void clearSpikeData()
	{
		synchronized(sensorData)
		{
			sensorData.clear();
		}
	}
	
	@Override
	public void signalEventData(Event evt)
	{
		synchronized(eventData)
		{
			eventData.add(evt);
		}
	}
	
	public int getAvailableEvents()
	{
		synchronized(eventData)
		{
			return eventData.size();
		}
	}
	
	public LinkedList<Event> getEventData()
	{
		synchronized(eventData)
		{
			LinkedList<Event> retList = new LinkedList<Event>(eventData);
			
			eventData.clear();
			return retList;
		}
	}
	
	public void clearEventData()
	{
		synchronized(eventData)
		{
			eventData.clear();
		}
	}
}
