package pipeClientThread;

import java.util.HashMap;
import java.util.LinkedList;

import pipeClient.PipeClient.EventEvent;
import pipeClient.PipeClient.StateEvent;
import pipeClient.Event;
import pipeClient.PipeClient;
import pipeClient.PipeClientListener;
import pipeClient.Spike;

public class McsCMOSPipeMonitor extends Thread implements PipeClientListener
{

	private String address;
	private PipeClient client;
	private HashMap<Integer, Integer> sensors;
	private Integer totalSpikeCount;
	private volatile boolean stop = false;
	
	public McsCMOSPipeMonitor(String address)
	{
		this.address = address;
		
		sensors = new HashMap<Integer, Integer>();
		
		client = new PipeClient();
		client.addListener(this);
	}
	
	public boolean connect()
	{
		client.start(address);
		return client.connect();
	}
	
	@Override
	public void run()
	{
		while (!stop)
		{
			client.listenForData();
		}
		client.close();
	}
	
	public void terminate()
	{
		stop = true;
	}
	
	@Override
	public void signalClientState(StateEvent state)
	{
		System.out.println(state.getState() + ":");
		System.out.println(state.getMessage());
	}

	@Override
	public void signalClientEvent(EventEvent event)
	{
		System.err.println(event.getEvent() + ":");
		System.err.println(event.getMessage());
	}

	@Override
	public void signalSpikeData(HashMap<Integer, LinkedList<Spike>> spikes)
	{
		synchronized(sensors)
		{	
			sensors.clear();
			totalSpikeCount = 0;
			for (Integer sensor : spikes.keySet())
			{
				if (sensors.containsKey(sensor)) 
				{
					sensors.put(sensor, sensors.get(sensor) + 1);
				}
				else 
				{
					sensors.put(sensor, 1);
				}
				totalSpikeCount += spikes.get(sensor).size();
			}
			
			System.out.println("Spikes arrived: " + sensors.size() + " sensors with " + totalSpikeCount + " spikes in total.");
		}
	}

	@Override
	public void signalEventData(Event evt)
	{
		System.out.println("Event arrived: " + evt.getLabel() + " with data " + evt.getData() + " at time " + evt.getTimeStamp() + ". ID: " + evt.getID() + ", source: " + evt.getEventSource());
	}
}
