function rate = getSpikeRate(spikeData, durationInSeconds)
% function rate = getSpikeRate(spikeData, durationInSeconds)
% 
% This function takes the cell array with spike data and the duration in
% seconds over which the spike data was collected and returns a (65 x 65)
% matrix of spike rates in [Hz].
%
% Input:
%   spikeData           -   (1 x n) cell array of spike data, each cell
%                           containing a (1 x m) vector of spike structs as
%                           generated by the "retrieveData" function.
%   durationInSeconds   -   scalar, the duration in seconds for which the
%                           spike data was collected.
%
% Output:
%   rate                -   (65 x 65) matrix of spike rates in Hz

    rate = zeros(65);
    
    for si = 1:length(spikeData)
        if ~isempty(spikeData{si})
            s = spikeData{si}(1);
            index = s.sensorID;

            x = floor((index - 1) / 65) + 1;
            y = mod((index - 1), 65) + 1;

            rate(y,x) = length(spikeData{si}) / durationInSeconds;
        end
    end