function [rateFigureHandle, overlayAxesHandle] = initPlots(varargin)
% function [rateFigureHandle, overlayAxesHandle] = initPlots(varargin)
%
% Initializes the spike rate and the spike overlay plot figures. Returns
% handles for use with other plot functions.
%
% Input:
%   colormap            -   (optional) Colormap for the spike rate display.
%                           Default is the flipped 'gray' colormap, i.e. a
%                           spike rate of zero is white, max spike rate is
%                           black.
%
% Output:
%   rateFigureHandle    -   Handle to the spike rate figure.
%   overlayAxesHandle   -   Handle to the axes of the spike overlay figure.

    figure(2);
    clf
    overlayAxesHandle = gca;
    
    rateFigureHandle = figure(1);
    clf
    h = guihandles(rateFigureHandle);
    h.CurrentSensor = 1;
    guidata(rateFigureHandle, h);
    
    if ~isempty(varargin)
        colormap(varargin{1});
    else
        colormap(flipud(colormap('gray')));
    end
    
    set(gcf, 'WindowButtonDownFcn',@mouseHandler);
end