% The host name of the machine running the CMOS server. '.' for local
% machine.
CMOSMeaMachineName = '.';

% The waiting period between each update of the plots.
plotUpdateRate = 0.5; %sec

% The waiting period between each check of any incoming events
eventUpdateRate = 0.05; %sec

% The number of updates to the plots.
% Not really the actual duration, because plotting etc. takes time as well
duration = 300; %sec

% The maximum spike rate displayed in the spike rate plot (for color
% scaling)
maxSpikeRate = 20; %Hz

% Initialize plots
[figHandle, overlayAxesHandle] = initPlots();

% Create listener connected to the CMOS server.
listener = makeCMOSDataListener(CMOSMeaMachineName);

% Start collecting data
listener.start();

firstTimeStamp = -1;
lastTimeStamp = 0;
resid = cell(1,65*65);

% Data retrieval and display loop
while firstTimeStamp == -1 || currentTimeStamp < firstTimeStamp + duration
   
   pause(eventUpdateRate)
   
   % check for any new events
   if listener.getAvailableEvents > 0
        [timerEvts, otherEvts] = retrieveEvents(listener);
        plotEvents(otherEvts);
        
        % check for timer events
        if ~isempty(timerEvts)
            currentTimeStamp = timerEvts(end).TimeStamp / 1e6;
            if firstTimeStamp == -1
                firstTimeStamp = currentTimeStamp;
            end
            
            % check if the plots need to be updated
            if currentTimeStamp - lastTimeStamp >= plotUpdateRate
               [data, resid] = retrieveData(listener, currentTimeStamp * 1e6, resid);
               rate = getSpikeRate(data, currentTimeStamp - lastTimeStamp);
               plotSpikeRate(rate, maxSpikeRate, figHandle);
               plotCurrentSensor(data, figHandle, overlayAxesHandle);
               
               lastTimeStamp = currentTimeStamp;
            end
        end
   end
end

% Terminate data collection and disconnect
listener.terminate();