function t = makeCMOSDataListener(machineName)
% function t = makeCMOSDataListener(machineName)
%
% Returns a pipeClientThread.McsCMOSPipeThread object that can be used to
% receive data from a CMOSPipeServer on a remote machine. The listener
% object will attempt to connect to the server on creation. If the
% connection fails, call t.connect() once the server is running. Calling
% t.start() will start the data collection and t.terminate() will terminate
% it. 
% Matlab tends to crash if too much data accumulates, so remember to
% either retrieve the data often (e.g. via the 'retrieveData' function or
% something similar) or call t.terminate() rather soon.
%
% Input:
%   machineName         -   string, the host name of the machine
%                           running the server.
%
% Output:
%   t                   -   A (connected) pipeClientThread.McsCMOSPipeClientThread
%                           object.

    address = ['\\\\' machineName '\\pipe\\' char(pipeClient.Security.PipeName)];

    t = handle(pipeClientThread.McsCMOSPipeClientThread(address));
    t.connect();
    
end