function plotCurrentSensor(data, rateFigureHandle, overlayAxesHandle)
% function plotCurrentSensor(data, rateFigureHandle, overlayAxesHandle)
%
% Plots an overlay of the spike waveforms collected for the current sensor.
%
% Input: 
%   data            -   (1 x 65*65) cell array of spike data for the different
%                       sensors as created by the 'retrieveData' function
%   rateFigureHandle-   Handle to the spike rate figure as created by the
%                       'initPlots' function.
%   overlayAxesHandle-  Handle to the plot axes of the overlay plot figure
%                       as created by the 'initPlots' function.

    h = guidata(rateFigureHandle);
    currentSensor = h.CurrentSensor;

    if ~isempty(data{currentSensor})
        spikeList = data{currentSensor};
        for i = 1:length(spikeList)
            spike = spikeList(i);
            if spike.hasWaveForm
                plot(overlayAxesHandle, spike.waveForm)
                hold(overlayAxesHandle,'on')
            end
        end
        hold(overlayAxesHandle,'off')
    else
        cla(overlayAxesHandle)
    end
    
    title(overlayAxesHandle, ['Sensor ' num2str(currentSensor)])
    xlabel(overlayAxesHandle, 'Samples')
    ylabel(overlayAxesHandle, '\muV')

end