function plotSpikeRate(spikeRate, maxRate, rateFigureHandle)
% function plotSpikeRate(spikeRate, maxRate, rateFigureHandle)
%
% Plot spike rates in a 65 x 65 grid.
%
% Input:
%   spikeRate           -   (65 x 65) matrix of spike rates, generated e.g.
%                           by the 'getSpikeRate' function
%   maxRate             -   scalar, used as the maximum for color scaling
%   rateFigureHandle    -   handle to the figure showing the spike rates.
    
    if exist('groot','builtin')
        set(groot, 'CurrentFigure', rateFigureHandle);
    else
        set(0, 'CurrentFigure', rateFigureHandle);
    end
    axHandle = gca;
    imagesc(spikeRate, 'Parent', axHandle, [0 maxRate]);
    
    h = colorbar('peer', axHandle);
    set(get(h, 'title'), 'string', 'Spike Rate [Hz]');
end